==> mob_variants_api_zenxarch-0.0.1-sources.jar: org/codeberg/zenxarch/mob_variants_api/variant/MobAttachments.java <==
package org.codeberg.zenxarch.mob_variants_api.variant;

import com.mojang.serialization.Codec;
import net.fabricmc.fabric.api.attachment.v1.AttachmentRegistry;
import net.fabricmc.fabric.api.attachment.v1.AttachmentSyncPredicate;
import net.fabricmc.fabric.api.attachment.v1.AttachmentType;
import net.minecraft.class_12079.class_10726;
import net.minecraft.class_1266;
import net.minecraft.class_1308;
import net.minecraft.class_173;
import net.minecraft.class_181;
import net.minecraft.class_3218;
import net.minecraft.class_52;
import net.minecraft.class_5321;
import net.minecraft.class_6885;
import net.minecraft.class_6895;
import net.minecraft.class_7924;
import net.minecraft.class_8110;
import net.minecraft.class_8567;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9652;
import org.codeberg.zenxarch.mob_variants_api.MobVariantsApiMod;
import org.codeberg.zenxarch.mob_variants_api.variant.effect.MobEffect;

public final class MobAttachments {
  private MobAttachments() {
    throw new IllegalStateException("Utility class");
  }

  public static final AttachmentType<class_10726> TEXTURE_OVERRIDE =
      createAttachment("texture_override", class_10726.field_56393, class_10726.field_56395);

  public static final AttachmentType<class_9652> EQUIPMENT_TABLE =
      createAttachment("equipment_table", class_9652.field_51375);

  public static final AttachmentType<class_5321<class_52>> LOOT_TABLE =
      createAttachment("loot_table", class_5321.method_39154(class_7924.field_50079));

  public static final AttachmentType<class_6885<class_8110>> INVULNERABLE_TO =
      createAttachment("invulnerable_to", class_6895.method_40340(class_7924.field_42534));

  public static final AttachmentType<OverlayAttachment> OVERLAY =
      createAttachment("overlay", OverlayAttachment.CODEC, OverlayAttachment.PACKET_CODEC);

  public static final AttachmentType<MobEffect> ON_SPAWN = createMobEvent("on_spawn");
  public static final AttachmentType<MobEffect> ON_TICK = createMobEvent("on_tick");
  public static final AttachmentType<MobEffect> ON_ATTACK = createMobEvent("on_attack");
  public static final AttachmentType<MobEffect> ON_DAMAGE = createMobEvent("on_damage");
  public static final AttachmentType<MobEffect> ON_DEATH = createMobEvent("on_death");
  public static final AttachmentType<MobEffect> ON_KILL = createMobEvent("on_kill");
  public static final AttachmentType<MobEffect> ON_KILLED = createMobEvent("on_killed");

  public static final AttachmentType<Boolean> RENDER_HEAD =
      createAttachment("render_head", Codec.BOOL, class_9135.field_48547);

  private static AttachmentType<MobEffect> createMobEvent(String id) {
    return AttachmentRegistry.createPersistent(MobVariantsApiMod.id(id), MobEffect.CODEC);
  }

  private static <T> AttachmentType<T> createAttachment(String id, Codec<T> codec) {
    return AttachmentRegistry.createPersistent(MobVariantsApiMod.id(id), codec);
  }

  private static <T> AttachmentType<T> createAttachment(
      String id, Codec<T> codec, class_9139<? super class_9129, T> packetCodec) {
    return AttachmentRegistry.create(
        MobVariantsApiMod.id(id),
        builder -> builder.persistent(codec).syncWith(packetCodec, AttachmentSyncPredicate.all()));
  }

  public static void initEquipment(
      class_1308 mob, class_3218 world, class_9652 table, class_1266 difficulty) {
    mob.method_59663(
        table.comp_2621(),
        new class_8567.class_8568(world)
            .method_51874(class_181.field_24424, mob.method_73189())
            .method_51874(class_181.field_1226, mob)
            .method_51871(difficulty.method_5458())
            .method_51875(class_173.field_50217),
        table.comp_2622());
  }

  public static void initialize() {
    // Force load class
  }
}

==> mob_variants_api_zenxarch-0.0.2-sources.jar: org/codeberg/zenxarch/mob_variants_api/variant/MobAttachments.java <==
package org.codeberg.zenxarch.mob_variants_api.variant;

import com.mojang.serialization.Codec;
import net.fabricmc.fabric.api.attachment.v1.AttachmentRegistry;
import net.fabricmc.fabric.api.attachment.v1.AttachmentSyncPredicate;
import net.fabricmc.fabric.api.attachment.v1.AttachmentType;
import net.minecraft.class_12079.class_10726;
import net.minecraft.class_1266;
import net.minecraft.class_1308;
import net.minecraft.class_173;
import net.minecraft.class_181;
import net.minecraft.class_3218;
import net.minecraft.class_52;
import net.minecraft.class_5321;
import net.minecraft.class_6885;
import net.minecraft.class_6895;
import net.minecraft.class_7924;
import net.minecraft.class_8110;
import net.minecraft.class_8567;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9652;
import org.codeberg.zenxarch.mob_variants_api.MobVariantsApiMod;
import org.codeberg.zenxarch.mob_variants_api.variant.effect.MobEffect;

public final class MobAttachments {
  private MobAttachments() {
    throw new IllegalStateException("Utility class");
  }

  public static final AttachmentType<class_10726> TEXTURE_OVERRIDE =
      createAttachment("texture_override", class_10726.field_56393, class_10726.field_56395);

  public static final AttachmentType<class_9652> EQUIPMENT_TABLE =
      createAttachment("equipment_table", class_9652.field_51375);

  public static final AttachmentType<class_5321<class_52>> LOOT_TABLE =
      createAttachment("loot_table", class_5321.method_39154(class_7924.field_50079));

  public static final AttachmentType<class_6885<class_8110>> INVULNERABLE_TO =
      createAttachment("invulnerable_to", class_6895.method_40340(class_7924.field_42534));

  public static final AttachmentType<OverlayAttachment> OVERLAY =
      createAttachment("overlay", OverlayAttachment.CODEC, OverlayAttachment.PACKET_CODEC);

  public static final AttachmentType<MobEffect> ON_SPAWN = createMobEvent("on_spawn");
  public static final AttachmentType<MobEffect> ON_TICK = createMobEvent("on_tick");
  public static final AttachmentType<MobEffect> ON_ATTACK = createMobEvent("on_attack");
  public static final AttachmentType<MobEffect> ON_DAMAGE = createMobEvent("on_damage");
  public static final AttachmentType<MobEffect> ON_DEATH = createMobEvent("on_death");
  public static final AttachmentType<MobEffect> ON_KILL = createMobEvent("on_kill");
  public static final AttachmentType<MobEffect> ON_KILLED = createMobEvent("on_killed");
  public static final AttachmentType<MobEffect> ON_ADD_TARGET = createMobEvent("on_add_target");
  public static final AttachmentType<MobEffect> ON_REMOVE_TARGET =
      createMobEvent("on_remove_target");

  public static final AttachmentType<Boolean> RENDER_HEAD =
      createAttachment("render_head", Codec.BOOL, class_9135.field_48547);

  private static AttachmentType<MobEffect> createMobEvent(String id) {
    return AttachmentRegistry.createPersistent(MobVariantsApiMod.id(id), MobEffect.CODEC);
  }

  private static <T> AttachmentType<T> createAttachment(String id, Codec<T> codec) {
    return AttachmentRegistry.createPersistent(MobVariantsApiMod.id(id), codec);
  }

  private static <T> AttachmentType<T> createAttachment(
      String id, Codec<T> codec, class_9139<? super class_9129, T> packetCodec) {
    return AttachmentRegistry.create(
        MobVariantsApiMod.id(id),
        builder -> builder.persistent(codec).syncWith(packetCodec, AttachmentSyncPredicate.all()));
  }

  public static void initEquipment(
      class_1308 mob, class_3218 world, class_9652 table, class_1266 difficulty) {
    mob.method_59663(
        table.comp_2621(),
        new class_8567.class_8568(world)
            .method_51874(class_181.field_24424, mob.method_73189())
            .method_51874(class_181.field_1226, mob)
            .method_51871(difficulty.method_5458())
            .method_51875(class_173.field_50217),
        table.comp_2622());
  }

  public static void initialize() {
    // Force load class
  }
}
